import{u as h,D as B,a as D,b,c as v,d as w,m as x,f as C}from"./reka-ui-Ve6GQT9e.js";import{d as c,D as d,u as a,A as f,E as n,h as i,J as P,K as $,e as r,H as _,I as k,f as z,ak as O,b as A,ad as E}from"./lucide-BsOfcLnq.js";import{c as m}from"./index-CyXUjyDM.js";import{m as y}from"./vueuse-CmMrRm2c.js";const M=c({__name:"Dialog",props:{open:{type:Boolean},defaultOpen:{type:Boolean},modal:{type:Boolean}},emits:["update:open"],setup(t,{emit:e}){const l=h(t,e);return(u,g)=>(r(),d(a(B),f({"data-slot":"dialog"},a(l)),{default:n(p=>[i(u.$slots,"default",P($(p)))]),_:3},16))}}),F=c({__name:"DialogOverlay",props:{forceMount:{type:Boolean},asChild:{type:Boolean},as:{},class:{}},setup(t){const e=t,s=y(e,"class");return(o,l)=>(r(),d(a(D),f({"data-slot":"dialog-overlay"},a(s),{class:a(m)("data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 fixed inset-0 !z-[9999] bg-black/80",e.class)}),{default:n(()=>[i(o.$slots,"default")]),_:3},16,["class"]))}}),R=c({inheritAttrs:!1,__name:"DialogContent",props:{forceMount:{type:Boolean},disableOutsidePointerEvents:{type:Boolean},asChild:{type:Boolean},as:{},class:{default:void 0},showCloseButton:{type:Boolean,default:!0}},emits:["escapeKeyDown","pointerDownOutside","focusOutside","interactOutside","openAutoFocus","closeAutoFocus"],setup(t,{emit:e}){const s=t,o=e,l=y(s,"class"),u=h(l,o);return(g,p)=>(r(),d(a(b),null,{default:n(()=>[_(F),_(a(v),f({"data-slot":"dialog-content"},{...g.$attrs,...a(u)},{class:a(m)("bg-background data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 fixed top-[50%] left-[50%] !z-[9999] grid w-full max-w-[calc(100%-2rem)] translate-x-[-50%] translate-y-[-50%] gap-4 rounded-lg border p-6 shadow-lg duration-200 sm:max-w-lg",s.class)}),{default:n(()=>[i(g.$slots,"default"),t.showCloseButton?(r(),d(a(w),{key:0,"data-slot":"dialog-close",class:"ring-offset-background focus:ring-ring data-[state=open]:bg-accent data-[state=open]:text-muted-foreground absolute top-4 right-4 rounded-xs opacity-70 transition-opacity hover:opacity-100 focus:ring- focus:ring-offset-2 focus:outline-hidden disabled:pointer-events-none [&_svg]:pointer-events-none [&_svg]:shrink-0 [&_svg:not([class*='size-'])]:size-4 mt-2"},{default:n(()=>[_(a(O)),p[0]||(p[0]=z("span",{class:"sr-only"},"Close",-1))]),_:1})):k("",!0)]),_:3},16,["class"])]),_:3}))}}),T=c({__name:"DialogHeader",props:{class:{}},setup(t){const e=t;return(s,o)=>(r(),A("div",{"data-slot":"dialog-header",class:E(a(m)("flex flex-col gap-2 text-center sm:text-left",e.class))},[i(s.$slots,"default")],2))}}),I=c({__name:"DialogTitle",props:{asChild:{type:Boolean},as:{},class:{}},setup(t){const e=t,s=y(e,"class"),o=x(s);return(l,u)=>(r(),d(a(C),f({"data-slot":"dialog-title"},a(o),{class:a(m)("text-lg leading-none font-semibold",e.class)}),{default:n(()=>[i(l.$slots,"default")]),_:3},16,["class"]))}});export{M as _,R as a,T as b,I as c};
