import{c as o}from"./index-CyXUjyDM.js";import{d as t,b as n,ad as r,u as c,h as l,e as p}from"./lucide-BsOfcLnq.js";const i=t({__name:"CardContent",props:{class:{}},setup(s){const a=s;return(e,d)=>(p(),n("div",{"data-slot":"card-content",class:r(c(o)("px-6",a.class))},[l(e.$slots,"default")],2))}});export{i as _};
