import{d as u,g as d,aY as f,u as o,b as p,ad as c,r as m,_ as b,e as v}from"./lucide-BsOfcLnq.js";import{y as x}from"./vueuse-CmMrRm2c.js";import{c as g}from"./index-CyXUjyDM.js";const R=u({__name:"Input",props:{defaultValue:{},modelValue:{},class:{}},emits:["update:modelValue"],setup(r,{expose:a,emit:l}){const e=r,t=x(e,"modelValue",l,{passive:!0,defaultValue:e.defaultValue}),i=m(null);return a({focus:()=>{i.value?.focus()}}),(w,s)=>d((v(),p("input",{ref_key:"inputRef",ref:i,"onUpdate:modelValue":s[0]||(s[0]=n=>b(t)?t.value=n:null),"data-slot":"input",class:c(o(g)("file:text-foreground placeholder:text-muted-foreground selection:bg-primary selection:text-primary-foreground dark:bg-input/30 border-input h-9 w-full min-w-0 rounded-md border bg-transparent px-3 py-1 text-base shadow-xs transition-[color,box-shadow] outline-none file:inline-flex file:h-7 file:border-0 file:bg-transparent file:text-sm file:font-medium disabled:pointer-events-none disabled:cursor-not-allowed disabled:opacity-50 md:text-sm","focus-visible:border-ring focus-visible:ring-ring/50 focus-visible:ring-[3px]","aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive",e.class))},null,2)),[[f,o(t)]])}});export{R as _};
