.user-name-box[data-v-a3b01284],.user-name-box[data-v-67fe20d4]{background:rgba(var(--v-theme-error),.08);border-left:3px solid rgb(var(--v-theme-error));padding:12px 16px;border-radius:4px;font-weight:500;font-size:.938rem}
