import{c as i}from"./index-CyXUjyDM.js";import{P as s}from"./reka-ui-Ve6GQT9e.js";import{c as n}from"./index-5I5X8kaN.js";import{d as o,D as d,u as t,ad as c,E as u,h as l,e as v}from"./lucide-BsOfcLnq.js";const x=o({__name:"Button",props:{variant:{default:"default"},size:{default:"default"},class:{default:void 0},asChild:{type:Boolean},as:{default:"button"}},setup(e){const a=e;return(r,f)=>(v(),d(t(s),{"data-slot":"button",as:e.as,"as-child":e.asChild,class:c(t(i)(t(g)({variant:e.variant,size:e.size}),a.class))},{default:u(()=>[l(r.$slots,"default")]),_:3},8,["as","as-child","class"]))}}),g=n("inline-flex items-center justify-center gap-2 whitespace-nowrap rounded-md text-sm font-medium transition-all disabled:pointer-events-none disabled:opacity-50 [&_svg]:pointer-events-none [&_svg:not([class*='size-'])]:size-4 shrink-0 [&_svg]:shrink-0 outline-none focus-visible:border-ring focus-visible:ring-ring/50 focus-visible:ring-[3px] aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive",{variants:{variant:{default:"bg-primary text-primary-foreground hover:bg-primary/90",destructive:"bg-destructive text-white hover:bg-destructive/90 focus-visible:ring-destructive/20 dark:focus-visible:ring-destructive/40 dark:bg-destructive/60",outline:"border bg-background shadow-xs hover:bg-accent hover:text-accent-foreground dark:bg-input/30 dark:border-input dark:hover:bg-input/50",secondary:"bg-secondary text-secondary-foreground hover:bg-secondary/80",ghost:"hover:bg-accent hover:text-accent-foreground dark:hover:bg-accent/50","ghost-icon":"hover:bg-transparent",link:"text-primary underline-offset-4 hover:underline"},size:{default:"h-9 px-4 py-2 has-[>svg]:px-3",sm:"h-8 rounded-md gap-1.5 px-3 has-[>svg]:px-2.5",lg:"h-10 rounded-md px-6 has-[>svg]:px-4",icon:"size-9","icon-xs":"size-2","icon-sm":"size-8","icon-lg":"size-10"}},defaultVariants:{variant:"default",size:"default"}});export{x as _};
