import{d,b as l,F as r,I as o,n as s,f as a,e as n}from"./lucide-BsOfcLnq.js";const u=d({__name:"NowPlayingBadge",props:{showBadge:{type:Boolean,default:!0},showIcon:{type:Boolean,default:!0},badgeStyle:{default:""},iconStyle:{default:""}},setup(e){return(i,t)=>(n(),l(r,null,[e.showBadge?(n(),l("span",{key:0,style:s(e.badgeStyle),class:"now-playing-badge","aria-label":"Now playing"}," Now playing ",4)):o("",!0),e.showIcon?(n(),l("div",{key:1,style:s(e.iconStyle),class:"now-playing-icon"},[...t[0]||(t[0]=[a("div",{class:"bar"},null,-1),a("div",{class:"bar"},null,-1),a("div",{class:"bar"},null,-1),a("div",{class:"bar"},null,-1)])],4)):o("",!0)],64))}});export{u as _};
