import{C as w}from"./Container-D40_MO5w.js";import{_ as L}from"./ProviderIcon.vue_vue_type_style_index_0_lang-CsLTxntn.js";import{f as a,_ as S}from"./index-CyXUjyDM.js";import{u as z}from"./vue-router-hLkI791z.js";import{b as T,a as B,c as _,T as f,U as C,d as l,a0 as v}from"./vuetify-DHCm6MV9.js";import{d as D,o as E,r as N,D as d,E as e,H as n,b as h,M as k,c as F,F as x,e as r,$ as c,a1 as m,I as A,u as y}from"./lucide-BsOfcLnq.js";import{u as H}from"./vue-i18n-CXdnqGsF.js";import"./index-kQIztB-E.js";import"./qrcode-DcFvg0BH.js";import"./marked-i_gIkIP3.js";import"./color-BTziYnFN.js";import"./vueuse-CmMrRm2c.js";/* empty css            */import"./swiper-BIRaDS2w.js";const R=D({__name:"SystemConfig",setup(U){const u=z(),{t:i}=H(),p=N([]),I=[{domain:"logging",name:"settings.system_logging",description:"settings.system_logging_description",icon:"mdi-text-box-search",route:"/settings/serverlogs"},{domain:"genre_management",name:"settings.genre_management",description:"settings.genre_management_description",icon:"mdi-compass-outline",route:"/settings/genremanagement"}],V=F(()=>[...p.value].sort((t,o)=>a.providerManifests[t.domain].name.localeCompare(a.providerManifests[o.domain].name))),$=t=>{const o=i(`settings.core_module.${t.domain}.name`);return o!==`settings.core_module.${t.domain}.name`?o:a.providerManifests[t.domain].name},b=t=>{const o=i(`settings.core_module.${t.domain}.description`);return o!==`settings.core_module.${t.domain}.description`?o:a.providerManifests[t.domain].description},g=function(t){t.route?u.push(t.route):u.push(`/settings/editcore/${t.domain}`)};return E(async()=>{p.value=await a.getCoreConfigs()}),(t,o)=>(r(),d(w,{variant:"comfortable",class:"settings-overview"},{default:e(()=>[n(B,{class:"settings-main-card"},{default:e(()=>[n(T,{class:"settings-list"},{default:e(()=>[(r(!0),h(x,null,k(V.value,s=>(r(),d(_,{key:s.domain,ripple:!0,class:"settings-list-item",onClick:M=>g(s)},{prepend:e(()=>[n(v,{color:"blue",size:"48"},{default:e(()=>[n(L,{domain:s.domain,size:24,color:"white"},null,8,["domain"])]),_:2},1024)]),append:e(()=>[s.last_error?(r(),d(l,{key:0,color:"red",icon:"mdi-alert-circle",class:"mr-2",title:s.last_error},null,8,["title"])):A("",!0),n(l,{icon:"mdi-chevron-right"})]),default:e(()=>[n(f,{class:"text-h6"},{default:e(()=>[c(m($(s)),1)]),_:2},1024),n(C,null,{default:e(()=>[c(m(b(s)),1)]),_:2},1024)]),_:2},1032,["onClick"]))),128)),(r(),h(x,null,k(I,s=>n(_,{key:s.domain,ripple:!0,class:"settings-list-item",onClick:M=>g(s)},{prepend:e(()=>[n(v,{color:"purple",size:"48"},{default:e(()=>[n(l,{icon:s.icon,size:"24",color:"white"},null,8,["icon"])]),_:2},1024)]),append:e(()=>[n(l,{icon:"mdi-chevron-right"})]),default:e(()=>[n(f,{class:"text-h6"},{default:e(()=>[c(m(y(i)(s.name)),1)]),_:2},1024),n(C,null,{default:e(()=>[c(m(y(i)(s.description)),1)]),_:2},1024)]),_:2},1032,["onClick"])),64))]),_:1})]),_:1})]),_:1}))}}),se=S(R,[["__scopeId","data-v-e98f2eee"]]);export{se as default};
