import{c as a}from"./index-CyXUjyDM.js";import{d as r,b as t,ad as l,u as n,h as c,e as f}from"./lucide-BsOfcLnq.js";const i=r({__name:"DialogFooter",props:{class:{}},setup(e){const s=e;return(o,m)=>(f(),t("div",{"data-slot":"dialog-footer",class:l(n(a)("flex flex-col-reverse gap-2 sm:flex-row sm:justify-end",s.class))},[c(o.$slots,"default")],2))}});export{i as _};
