import{c as r}from"./index-CyXUjyDM.js";import{d as o,b as t,ad as c,u as n,h as d,e as l}from"./lucide-BsOfcLnq.js";const u=o({__name:"Card",props:{class:{}},setup(a){const s=a;return(e,p)=>(l(),t("div",{"data-slot":"card",class:c(n(r)("bg-card text-card-foreground flex flex-col gap-6 rounded-xl border py-6 shadow-sm",s.class))},[d(e.$slots,"default")],2))}});export{u as _};
