.empty-state[data-v-7459f4e1]{display:flex;flex-direction:column;align-items:center;justify-content:center;padding:48px 24px;text-align:center}.empty-state[data-v-628ad67c]{display:flex;flex-direction:column;align-items:center;justify-content:center;padding:48px 24px}.user-profile[data-v-816dbecc]{height:100%;display:flex;flex-direction:column}.profile-container[data-v-816dbecc]{padding:24px 20px;max-width:900px;margin:0 auto;width:100%}.profile-content[data-v-816dbecc]{display:flex;flex-direction:column}@media(max-width:600px){.profile-container[data-v-816dbecc]{padding:12px}}
